;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "vterm" "20260706.1652"
  "Fully-featured terminal emulator."
  '((emacs "25.1"))
  :url "https://github.com/akermu/emacs-libvterm"
  :commit "9a32a4afce25647282bc8a8792468e41bc64adf4"
  :revdesc "9a32a4afce25"
  :keywords '("terminals")
  :authors '(("Lukas Fürmetz" . "fuermetz@mailbox.org"))
  :maintainers '(("Lukas Fürmetz" . "fuermetz@mailbox.org")))
